@@ -74,6 +74,10 @@
   (/show "testing '/SHOW" *print-length* *print-level*) ; show anything
   (unless (!c-runtime-noinform-p)
     (write-string "COLD-INIT... "))
+  ;; Establish **initial-handler-clusters**
+  (show-and-call sb-kernel::!target-error-cold-init)
+  ;; And now *CURRENT-THREAD* and *HANDLER-CLUSTERS*
+  (sb-thread::init-initial-thread)
 
   ;; Assert that FBOUNDP doesn't choke when its answer is NIL.
   ;; It was fine if T because in that case the legality of the arg is certain.
@@ -83,21 +87,15 @@
   ;; Anyone might call RANDOM to initialize a hash value or something;
   ;; and there's nothing which needs to be initialized in order for
   ;; this to be initialized, so we initialize it right away.
-  ;; Indeed, INIT-INITIAL-THREAD needs a random number.
   (show-and-call !random-cold-init)
 
-  ;; Ensure that *CURRENT-THREAD* and *HANDLER-CLUSTERS* have sane values.
-  ;; create_thread_struct() assigned NIL/unbound-marker respectively.
-  (sb-thread::init-initial-thread)
-  (show-and-call sb-kernel::!target-error-cold-init)
-
   ;; Putting data in a synchronized hashtable (*PACKAGE-NAMES*)
   ;; requires that the main thread be properly initialized.
   (show-and-call thread-init-or-reinit)
   ;; Printing of symbols requires that packages be filled in, because
   ;; OUTPUT-SYMBOL calls FIND-SYMBOL to determine accessibility.
   (show-and-call !package-cold-init)
-  (setq *print-pprint-dispatch* (sb-pretty::make-pprint-dispatch-table))
+  (setq *print-pprint-dispatch* (sb-pretty::make-pprint-dispatch-table nil nil nil))
   ;; Because L-T-V forms have not executed, CHOOSE-SYMBOL-OUT-FUN doesn't work.
   (setf (symbol-function 'choose-symbol-out-fun)
         (lambda (&rest args) (declare (ignore args)) #'output-preserve-symbol))
@@ -274,9 +272,6 @@
   ;; The system is finally ready for GC.
   (/show0 "enabling GC")
   (setq *gc-inhibit* nil)
-  (/show0 "doing first GC")
-  (gc :full t)
-  (/show0 "back from first GC")
 
   ;; The show is on.
   (/show0 "going into toplevel loop")
