@@ -293,6 +293,7 @@ Examples:
                  (zerop *compiler-warning-count*)
                  (zerop *compiler-style-warning-count*)
                  (zerop *compiler-note-count*))
+      (fresh-line *error-output*)
       (pprint-logical-block (*error-output* nil :per-line-prefix "; ")
         (format *error-output* "~&compilation unit ~:[finished~;aborted~]"
                 abort-p)
@@ -575,6 +576,9 @@ necessary, since type inference may take arbitrarily long to converge.")
             (maybe-mumble "copy ")
             (copy-propagate component))
 
+          (when *compiler-trace-output*
+            (format *compiler-trace-output*
+                    "~|~%;;;; component: ~S~2%" (component-name component)))
           (ir2-optimize component)
 
           (select-representations component)
@@ -608,7 +612,8 @@ necessary, since type inference may take arbitrarily long to converge.")
           (optimize-constant-loads component)
           (when *compiler-trace-output*
             (when (memq :ir1 *compile-trace-targets*)
-              (describe-component component *compiler-trace-output*))
+              (let ((*standard-output* *compiler-trace-output*))
+                (print-all-blocks component)))
             (when (memq :ir2 *compile-trace-targets*)
              (describe-ir2-component component *compiler-trace-output*)))
 
@@ -619,11 +624,13 @@ necessary, since type inference may take arbitrarily long to converge.")
                       (and (memq :vop *compile-trace-targets*)
                            *compiler-trace-output*)))
                 (generate-code component))
+            (declare (ignorable text-length fun-table))
 
             (let ((bytes (sb-assem:segment-contents-as-vector segment))
                   (object *compile-object*)
                   (*elsewhere-label* elsewhere-label)) ; KLUDGE
 
+              #-sb-xc-host
               (when (and *compiler-trace-output*
                          (memq :disassemble *compile-trace-targets*))
                 (let ((ranges
@@ -633,10 +640,8 @@ necessary, since type inference may take arbitrarily long to converge.")
                                                  sb-vm:word-shift))
                                          (or (cadr list) text-length)))
                                  fun-table)))
-                  (declare (ignorable ranges))
                   (format *compiler-trace-output*
                           "~|~%disassembly of code for ~S~2%" component)
-                  #-sb-xc-host
                   (sb-disassem:disassemble-assem-segment
                    bytes ranges *compiler-trace-output*)))
 
@@ -785,13 +790,6 @@ necessary, since type inference may take arbitrarily long to converge.")
 
 ;;;; trace output
 
-;;; Print out some useful info about COMPONENT to STREAM.
-(defun describe-component (component *standard-output*)
-  (declare (type component component))
-  (format t "~|~%;;;; component: ~S~2%" (component-name component))
-  (print-all-blocks component)
-  (values))
-
 (defun describe-ir2-component (component *standard-output*)
   (format t "~%~|~%;;;; IR2 component: ~S~2%" (component-name component))
   (format t "entries:~%")
@@ -1229,9 +1227,8 @@ necessary, since type inference may take arbitrarily long to converge.")
     (setf (component-name component) (debug-name 'initial-component debug-name-tail)
           (component-kind component) :initial)
     (let* ((fun (let ((*allow-instrumenting* t))
-                  (funcall #'ir1-convert-lambdalike
-                           lambda-expression
-                           :source-name source-name)))
+                  (ir1-convert-lambdalike lambda-expression
+                                          :source-name source-name)))
            ;; Convert the XEP using the policy of the real function. Otherwise
            ;; the wrong policy will be used for deciding whether to type-check
            ;; the parameters of the real function (via CONVERT-CALL /
@@ -1897,19 +1894,14 @@ SPEED and COMPILATION-SPEED optimization values, and the
                   (open-fasl-output coutput-file-name
                                     (namestring input-pathname))))
           (when trace-file
-            (if (streamp trace-file)
-                (setf *compiler-trace-output* trace-file)
-                (let* ((default-trace-file-pathname
-                         (make-pathname :type "trace" :defaults input-pathname))
-                       (trace-file-pathname
-                         (if (eql trace-file t)
-                             default-trace-file-pathname
-                             (merge-pathnames trace-file
-                                              default-trace-file-pathname))))
-                  (setf *compiler-trace-output*
-                        (open trace-file-pathname
-                              :if-exists :supersede
-                              :direction :output)))))
+            (setf *compiler-trace-output*
+                  (if (streamp trace-file)
+                      trace-file
+                      (open (merge-pathnames
+                             (if (eql trace-file t) "" trace-file)
+                             (make-pathname :type "trace" :defaults
+                                            (fasl-output-stream fasl-output)))
+                            :if-exists :supersede :direction :output))))
 
           (when sb-xc:*compile-verbose*
             (print-compile-start-note source-info))
@@ -1935,7 +1927,8 @@ SPEED and COMPILATION-SPEED optimization values, and the
       (when sb-xc:*compile-verbose*
         (print-compile-end-note source-info (not abort-p)))
 
-      (when *compiler-trace-output*
+      ;; Don't nuke stdout if you use :trace-file *standard-output*
+      (when (and trace-file (not (streamp trace-file)))
         (close *compiler-trace-output*)))
 
     ;; CLHS says that the first value is NIL if the "file could not
