@@ -183,17 +183,11 @@
       (seal-class class))))
 
 (defun process-inline-declaration (name kind)
+  (declare (type (and inlinep (not null)) kind))
   ;; since implicitly it is a function, also scrubs *FREE-FUNS*
   (proclaim-as-fun-name name)
-  ;; Check for problems before touching globaldb,
-  ;; so that the report function can see the old value.
-  (let ((newval
-         (ecase kind
-          (inline :inline)
-          (notinline :notinline)
-          (maybe-inline :maybe-inline))))
-    (warn-if-inline-failed/proclaim name newval)
-    (setf (info :function :inlinep name) newval)))
+  (warn-if-inline-failed/proclaim name kind)
+  (setf (info :function :inlinep name) kind))
 
 (defun check-deprecation-declaration (state since form)
   (unless (typep state 'deprecation-state)
@@ -237,7 +231,7 @@
            form name))
   (with-single-package-locked-error
       (:symbol name "globally declaring ~A as a declaration proclamation"))
-  (setf (info :declaration :recognized name) t))
+  (setf (info :declaration :known name) t))
 
 ;;; ANSI defines the declaration (FOO X Y) to be equivalent to
 ;;; (TYPE FOO X Y) when FOO is a type specifier. This function
@@ -334,7 +328,7 @@
         (declaration
          (map-args #'process-declaration-declaration form))
         (t
-         (unless (info :declaration :recognized kind)
+         (unless (info :declaration :known kind)
            (compiler-warn "unrecognized declaration ~S" raw-form)))))))
 
 (defun sb-xc:proclaim (raw-form)
