@@ -12,7 +12,7 @@
 ;;;; provided with absolutely no warranty. See the COPYING and CREDITS
 ;;;; files for more information.
 
-(in-package "SB!C")
+(in-package "SB-C")
 
 ;;;; type predicate translation
 ;;;;
@@ -85,7 +85,31 @@
                     (let ((alien-type (alien-type-type-alien-type type)))
                       ;; If it's a lisp-rep-type, the CTYPE should be one already.
                       (aver (not (compute-lisp-rep-type alien-type)))
-                      `(sb!alien::alien-value-typep object ',alien-type)))
+                      `(sb-alien::alien-value-typep object ',alien-type)))
+                   #+(vop-translates sb-int:fixnump-instance-ref)
+                   ((and (type= type (specifier-type 'fixnum))
+                         (let ((use (lvar-uses object)))
+                           (and (combination-p use)
+                                (almost-immediately-used-p object use)
+                                (or (and (eq (lvar-fun-name (combination-fun use))
+                                             '%instance-ref)
+                                         (constant-lvar-p
+                                          (second (combination-args use))))
+                                    (member (lvar-fun-name (combination-fun use))
+                                            '(car cdr))))))
+                    ;; This is a disturbing trend, but it's the best way to
+                    ;; combine instructions in the compiler as it is
+                    ;; (as opposed to the compiler as we wish it would be).
+                    (case (lvar-fun-name (combination-fun (lvar-uses object)))
+                     (%instance-ref
+                      (splice-fun-args object '%instance-ref 2)
+                      `(lambda (obj i) (fixnump-instance-ref obj i)))
+                     (car
+                      (splice-fun-args object 'car 1)
+                      `(lambda (obj) (fixnump-car obj)))
+                     (cdr
+                      (splice-fun-args object 'cdr 1)
+                      `(lambda (obj) (fixnump-cdr obj)))))
                    (t
                     (give-up-ir1-transform)))))
       (cond ((not (types-equal-or-intersect otype type))
@@ -163,6 +187,22 @@
               (t
                (delay-ir1-transform node :constraint)
                'test-value)))))
+
+(deftransform %type-constraint ((x type) * * :node node)
+  (delay-ir1-transform node :constraint)
+  nil)
+
+(defoptimizer (%type-constraint constraint-propagate) ((x type) node gen)
+  (declare (ignore node))
+  (let ((var (ok-lvar-lambda-var x gen)))
+    (when var
+      (let ((type (lvar-value type)))
+        (list (list 'typep var
+                    (if (ctype-p type)
+                        type
+                        (handler-case (careful-specifier-type type)
+                          (t () nil)))
+                    nil))))))
 
 ;;;; standard type predicates, i.e. those defined in package COMMON-LISP,
 ;;;; plus at least one oddball (%INSTANCEP)
@@ -177,6 +217,8 @@
   ; (The ATOM predicate is handled separately as (NOT CONS).)
   (define-type-predicate bit-vector-p bit-vector)
   (define-type-predicate characterp character)
+  #+(and sb-unicode (or x86-64 arm64)) ;; others have a source-transform
+  (define-type-predicate base-char-p base-char)
   (define-type-predicate compiled-function-p compiled-function)
   (define-type-predicate complexp complex)
   (define-type-predicate complex-rational-p (complex rational))
@@ -212,7 +254,7 @@
 (define-source-transform atom (x)
   `(not (consp ,x)))
 
-#!+(and sb-unicode (not (or x86-64 arm64)))
+#+(and sb-unicode (not (or x86-64 arm64)))
 (define-source-transform base-char-p (x)
   `(typep ,x 'base-char))
 ;; CONS is implemented as (and list (not (eql nil))) where the 'and' is
@@ -220,8 +262,11 @@
 (deftransform consp ((x) ((not null)) * :important nil)
   '(listp x))
 
+;;; If X is known non-nil, then testing SYMBOLP can skip the "= NIL" part.
 (deftransform symbolp ((x) ((not null)) * :important nil)
   '(non-null-symbol-p x))
+(deftransform non-null-symbol-p ((object) (symbol) * :important nil)
+  `(not (eq object nil)))
 
 ;;;; TYPEP source transform
 
@@ -273,7 +318,7 @@
                  ((nil) 'real))))
     (ecase (numeric-type-complexp type)
       (:real
-       (cond #!+(or x86 x86-64 arm arm64) ;; Not implemented elsewhere yet
+       (cond #+(or x86 x86-64 arm arm64) ;; Not implemented elsewhere yet
              ((and
                (eql (numeric-type-class type) 'integer)
                (or (eql (numeric-type-low type) 0)
@@ -317,7 +362,7 @@
              (compiler-notify "can't open-code test of unknown type ~S"
                               (type-specifier type)))
            `(let ((object ,object)
-                  (cache (load-time-value (cons #'sb!kernel::cached-typep ',spec)
+                  (cache (load-time-value (cons #'sb-kernel::cached-typep ',spec)
                                           t)))
               (truly-the (values t &optional)
                          (funcall (truly-the function (car (truly-the cons cache)))
@@ -478,7 +523,7 @@
           ((group-vector-length-type-tests object types))
           (t
            (multiple-value-bind (widetags more-types)
-               (sb!kernel::widetags-from-union-type types)
+               (sb-kernel::widetags-from-union-type types)
              (if widetags
                  `(or (%other-pointer-subtype-p ,object ',widetags)
                       (typep ,object '(or ,@(mapcar #'type-specifier more-types))))
@@ -546,20 +591,20 @@
     (or (and (= (length pairs) 1)
              (= (caar pairs) 0)
              (cond
-               #!+(and sb-unicode (or x86-64 arm64))
+               #+(and sb-unicode (or x86-64 arm64))
                ((= (cdar pairs) (1- base-char-code-limit))
                 `(base-char-p ,object))
-               ((= (cdar pairs) (1- sb!xc:char-code-limit))
+               ((= (cdar pairs) (1- sb-xc:char-code-limit))
                 `(characterp ,object))))
         (let ((n-code (gensym "CODE")))
           `(and (characterp ,object)
-                (let ((,n-code (sb!xc:char-code ,object)))
+                (let ((,n-code (sb-xc:char-code ,object)))
                   (or
                    ,@(loop for pair in pairs
                            collect
                            `(<= ,(car pair) ,n-code ,(cdr pair))))))))))
 
-#!+sb-simd-pack
+#+sb-simd-pack
 (defun source-transform-simd-pack-typep (object type)
   (if (type= type (specifier-type 'simd-pack))
       `(simd-pack-p ,object)
@@ -572,6 +617,19 @@
                     for index = (position type *simd-pack-element-types*)
                     collect `(eql ,n-tag ,index))))))))
 
+#+sb-simd-pack-256
+(defun source-transform-simd-pack-256-typep (object type)
+  (if (type= type (specifier-type 'simd-pack-256))
+      `(simd-pack-256-p ,object)
+      (let ((n-tag (gensym "TAG")))
+        `(and
+          (simd-pack-256-p ,object)
+          (let ((,n-tag (%simd-pack-256-tag ,object)))
+            (or ,@(loop
+                    for type in (simd-pack-256-type-element-type type)
+                    for index = (position type *simd-pack-element-types*)
+                    collect `(eql ,n-tag ,index))))))))
+
 ;;; Return the predicate and type from the most specific entry in
 ;;; *TYPE-PREDICATES* that is a supertype of TYPE.
 (defun find-supertype-predicate (type)
@@ -606,9 +664,9 @@
       (cond ((cdr dims)
              (values `(,header-test
                        ,@(when (eq (array-type-dimensions stype) '*)
-                           #!+x86-64
+                           #+x86-64
                            `((%array-rank= ,obj ,(length dims)))
-                           #!-x86-64
+                           #-x86-64
                            `((= (%array-rank ,obj) ,(length dims))))
                        ,@(loop for d in dims
                                for i from 0
@@ -646,15 +704,15 @@
         (eltype (array-type-specialized-element-type type)))
     (unless (or (type= eltype (array-type-specialized-element-type stype))
                 (eq eltype *wild-type*))
-      (let ((typecode (sb!vm:saetp-typecode (find-saetp-by-ctype eltype))))
+      (let ((typecode (sb-vm:saetp-typecode (find-saetp-by-ctype eltype))))
         (with-unique-names (data)
          (if (and headerp (not (array-type-complexp stype)))
              ;; If we know OBJ is an array header, and that the array is
              ;; simple, we also know there is exactly one indirection to
              ;; follow.
-             `(#!-x86-64
+             `(#-x86-64
                (eq (%other-pointer-widetag (%array-data ,obj)) ,typecode)
-               #!+x86-64
+               #+x86-64
                (widetag= (%array-data ,obj) ,typecode))
              `((do ((,data ,(if headerp `(%array-data ,obj) obj)
                            (%array-data ,data)))
@@ -689,7 +747,7 @@
                                   (eql (array-type-complexp type) t)
                                   (singleton-p dims)
                                   (and (neq et *wild-type*)
-                                       (sb!vm:saetp-complex-typecode
+                                       (sb-vm:saetp-complex-typecode
                                         (find-saetp-by-ctype (array-type-element-type type))))))
                     (simple-array-header-p
                       (and (null (array-type-complexp stype))
@@ -749,6 +807,8 @@
        (delay-ir1-transform node :constraint)
        (transform-instance-typep class)))))
 
+;;; This transform contains more comments than code. I wish there were some way
+;;; to express it more simply.
 (defun transform-instance-typep (class)
   (let* ((name (classoid-name class))
           (layout (let ((res (info :type :compiler-layout name)))
@@ -813,9 +873,9 @@
                                      (eq object-layout ',other-layout))))
                              ;; FIXME: not defined in time for make-host-1,
                              ;; so the cross-compiler isn't getting this branch.
-                             #!+(vop-named sb!vm::layout-eq)
+                             #+(vop-named sb-vm::layout-eq)
                              ((equal layout-getter '(%instance-layout object))
-                              `(sb!vm::layout-eq object ',layout))
+                              `(sb-vm::layout-eq object ',layout))
                              (t
                               `(eq ,layout-getter ',layout)))))
                 (if pred
@@ -850,15 +910,37 @@
                      ;; (eq (data-vector-ref ...) k) has a single instruction form,
                      ;; but lacking that, force it into a single call
                      ;; that a vop can translate.
-                     #!+(and immobile-space x86-64)
-                     `(sb!vm::layout-inherits-ref-eq ; only implemented on x86-64
+                     #+(and immobile-space x86-64)
+                     `(sb-vm::layout-inherits-ref-eq ; only implemented on x86-64
                        (layout-inherits ,n-layout) ,depthoid ,layout)
-                     #!-(and immobile-space x86-64)
+                     #-(and immobile-space x86-64)
                      `(eq ,get-ancestor ,layout))
-                   (deeper-p `(> (layout-depthoid ,n-layout) ,depthoid)))
+                   (deeper-p
+                    #+(vop-translates sb-c::layout-depthoid-gt)
+                    `(layout-depthoid-gt ,n-layout ,depthoid)
+                    #-(vop-translates sb-c::layout-depthoid-gt)
+                    `(> (layout-depthoid ,n-layout) ,depthoid)))
               (aver (equal pred '(%instancep object)))
-              `(and ,pred
-                    (let ((,n-layout ,get-layout))
+              (case name
+                (structure-object
+                 (return-from transform-instance-typep
+                   `(and (%instancep object)
+                         (logtest (layout-%bits (%instance-layout object))
+                                  +structure-layout-flag+))))
+                (pathname
+                 (return-from transform-instance-typep
+                   `(and (%instancep object)
+                         (logtest (layout-%bits (%instance-layout object))
+                                  +pathname-layout-flag+)))))
+              ;; For shallow hierarchies, we can avoid reading the 'inherits'
+              ;; because the layout has the ancestor layouts directly in it.
+              ;; Not even a depthoid check is needed.
+              ;; Since only layouts for structure types will have ancestors
+              ;; populated, and this transform case is only for structures,
+              ;; there can be no false positives. STREAM and CONDITION types
+              ;; have a depthoid>0, but are not structure-classoid-p.
+              `(and (%instancep object)
+                    (let ((,n-layout (%instance-layout object)))
                       ;; we used to check for invalid layouts here,
                       ;; but in fact that's both unnecessary and
                       ;; wrong; it's unnecessary because structure
@@ -866,10 +948,22 @@
                       ;; because it is quite legitimate to pass an
                       ;; object with an invalid layout to a structure
                       ;; type test.
-                      ,(if abstract-base-p
-                           `(eq (if ,deeper-p ,get-ancestor ,n-layout) ,layout)
-                           `(cond ((eq ,n-layout ,layout) t)
-                                  (,deeper-p ,ancestor-layout-eq)))))))
+                      ,(let ((ancestor-slot (case depthoid
+                                             (2 'sb-kernel::layout-depth2-ancestor)
+                                             (3 'sb-kernel::layout-depth3-ancestor)
+                                             (4 'sb-kernel::layout-depth4-ancestor))))
+                         (if ancestor-slot
+                             (if abstract-base-p
+                                 `(or (eq (,ancestor-slot ,n-layout) ,layout)
+                                      (eq ,n-layout ,layout)) ; not likely
+                                 ;; Indifferent to order here. Might as well test
+                                 ;; for an exact match first.
+                                 `(or (eq ,n-layout ,layout)
+                                      (eq (,ancestor-slot ,n-layout) ,layout)))
+                             (if abstract-base-p
+                                 `(eq (if ,deeper-p ,get-ancestor ,n-layout) ,layout)
+                                 `(cond ((eq ,n-layout ,layout) t)
+                                        (,deeper-p ,ancestor-layout-eq)))))))))
            ((and layout (>= (layout-depthoid layout) 0))
             ;; hierarchical layout depths for other things (e.g.
             ;; CONDITION, STREAM)
@@ -924,15 +1018,12 @@
                      `(eql ,object ',value))))
          (handler-case
              (or
-              (let ((pred (cdr (assoc ctype *backend-type-predicates*
-                                      :test #'type=))))
+              (let ((pred (backend-type-predicate ctype)))
                 (when pred `(,pred ,object)))
-              (let ((pred (cdr (assoc (type-negation ctype)
-                                      *backend-type-predicates*
-                                      :test #'type=))))
+              (let ((pred (backend-type-predicate (type-negation ctype))))
                 (when pred `(not (,pred ,object)))))
            #+sb-xc-host
-           (sb!kernel::cross-type-warning
+           (sb-kernel::cross-type-warning
              nil))
          (typecase ctype
            (hairy-type
@@ -960,9 +1051,12 @@
             (source-transform-cons-typep object ctype))
            (character-set-type
             (source-transform-character-set-typep object ctype))
-           #!+sb-simd-pack
+           #+sb-simd-pack
            (simd-pack-type
             (source-transform-simd-pack-typep object ctype))
+           #+sb-simd-pack-256
+           (simd-pack-256-type
+            (source-transform-simd-pack-256-typep object ctype))
            (t nil))
          `(%typep ,object ',type))
         (values nil t))))
@@ -987,7 +1081,8 @@
   ;; weird roundabout way. -- WHN 2001-03-18
   (if (and (not env)
            (typep spec '(cons (eql quote) (cons t null))))
-      (source-transform-typep object (cadr spec))
+      (with-current-source-form (spec)
+        (source-transform-typep object (cadr spec)))
       (values nil t)))
 
 ;;;; coercion
@@ -1017,7 +1112,7 @@
                    dimensions-removed)
                (dolist (type types)
                  (unless (or (hairy-type-p type)
-                             (sb!kernel::negation-type-p type))
+                             (sb-kernel::negation-type-p type))
                    (multiple-value-bind (type et upgraded dimensions) (simplify type)
                      (push type array-types)
                      (push et element-types)
@@ -1063,25 +1158,63 @@
                     (error "~a is not a subtype of VECTOR." type)))))
     (simplify type)))
 
+
+(defun check-coerce (value-type to-type type-specifier node)
+  (flet ((fail ()
+           (compiler-warn "Cannot coerce ~s to ~s"
+                          (type-specifier value-type)
+                          (type-specifier to-type))
+           (setf (combination-kind node) :error)
+           (give-up-ir1-transform)))
+    (cond ((eq to-type *empty-type*)
+           (fail))
+          ((types-equal-or-intersect value-type to-type))
+          ((csubtypep to-type (specifier-type 'sequence))
+           (unless (csubtypep to-type (specifier-type 'sequence))
+             (fail)))
+          ((eql type-specifier 'character)
+           (unless (types-equal-or-intersect value-type
+                                             (specifier-type 'string))
+             (fail)))
+          ((csubtypep to-type (specifier-type 'complex))
+           (unless (types-equal-or-intersect value-type
+                                             (specifier-type 'number))
+             (fail)))
+
+          ((csubtypep to-type (specifier-type 'float))
+           (unless (types-equal-or-intersect value-type
+                                             (specifier-type 'real))
+             (fail)))
+          ((eq type-specifier 'function)
+           (unless (types-equal-or-intersect value-type
+                                             (specifier-type '(or symbol cons)))
+             (fail)))
+          (t
+           (fail)))))
+
 (deftransform coerce ((x type) (* *) * :node node)
   (unless (constant-lvar-p type)
     (give-up-ir1-transform))
   (let* ((tval (lvar-value type))
-         (tspec (ir1-transform-specifier-type tval)))
+         (tspec (ir1-transform-specifier-type tval))
+         (value-type (lvar-type x)))
+    (check-coerce value-type tspec tval node)
     ;; Note: The THE forms we use to wrap the results make sure that
     ;; specifiers like (SINGLE-FLOAT 0.0 1.0) can raise a TYPE-ERROR.
     (cond
-      ((eq tspec *empty-type*)
-       (compiler-warn "Can't coerce to NIL.")
-       (setf (combination-kind node) :error)
-       (give-up-ir1-transform))
-      ((csubtypep (lvar-type x) tspec)
+      ((csubtypep value-type tspec)
        'x)
       ((csubtypep tspec (specifier-type 'double-float))
        `(the ,tval (%double-float x)))
-      ;; FIXME: #!+long-float (t ,(error "LONG-FLOAT case needed"))
-      ((csubtypep tspec (specifier-type 'float))
+      ((csubtypep tspec (specifier-type 'single-float))
        `(the ,tval (%single-float x)))
+      ;; FIXME: #+long-float (t ,(error "LONG-FLOAT case needed"))
+      ((csubtypep tspec (specifier-type 'float))
+       (if (types-equal-or-intersect value-type (specifier-type 'float))
+           `(the ,tval (if (floatp x)
+                           x
+                           (%single-float x)))
+           `(the ,tval (%single-float x))))
       ((csubtypep tspec (specifier-type 'complex))
        (multiple-value-bind (part-type result-type)
            (cond ((and (numeric-type-p tspec)
@@ -1100,9 +1233,15 @@
               ((typep x ',tval)
                x)
               (t         ; X is COMPLEX, but not of the requested type
-               (the ,result-type
-                    (complex (coerce (realpart x) ',part-type)
-                             (coerce (imagpart x) ',part-type))))))))
+               ,(if (eq part-type 'rational)
+                    ;; Can't coerce non-rational to a rational and
+                    ;; CHECK-COERCE will warn, so just full call
+                    ;; COERCE and let it signal an error.
+                    `(locally (declare (notinline coerce))
+                       (coerce x ',tval))
+                    `(the ,result-type
+                          (complex (coerce (realpart x) ',part-type)
+                                   (coerce (imagpart x) ',part-type)))))))))
       ;; Special case STRING and SIMPLE-STRING as they are union types
       ;; in SBCL.
       ((member tval '(string simple-string))
@@ -1161,14 +1300,14 @@
         "~@<open coding coercion to ~S not implemented.~:@>"
         tval)))))
 
-(deftransform #!+64-bit unsigned-byte-64-p #!-64-bit unsigned-byte-32-p
+(deftransform #+64-bit unsigned-byte-64-p #-64-bit unsigned-byte-32-p
   ((value) (fixnum))
   `(>= value 0))
 
 (deftransform %other-pointer-p ((object))
   (let ((this-type
           (specifier-type '(or fixnum
-                            #!+64-bit single-float
+                            #+64-bit single-float
                             function
                             list
                             instance
